@@ -1,4 +1,8 @@
-{-# LANGUAGE TypeFamilies, QuasiQuotes, TemplateHaskell, MultiParamTypeClasses, OverloadedStrings #-}
+{-# LANGUAGE MultiParamTypeClasses #-}
+{-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE QuasiQuotes #-}
+{-# LANGUAGE TemplateHaskell #-}
+{-# LANGUAGE TypeFamilies #-}
 
 module YesodCoreTest.Csrf (csrfSpec, Widget, resourcesApp) where
 
@@ -10,7 +14,6 @@ import Network.Wai.Test
 import Web.Cookie
 import qualified Data.Map as Map
 import Data.ByteString.Lazy (fromStrict)
-import Data.Monoid ((<>))
 
 data App = App
 
@@ -79,7 +82,7 @@ csrfSpec = describe "A Yesod application with the defaultCsrfMiddleware" $ do
 
         res <- request (defaultRequest { requestMethod = "POST", requestHeaders = [(defaultCsrfHeaderName, csrfValue <> "foo")] })
         assertStatus 403 res
-        
+
     it "403s write requests with the wrong CSRF param" $ runner $ do
         getRes <- request defaultRequest
         assertStatus 200 getRes
